@@ -1,40 +1,52 @@
-material_dropdown <- function(input_id, label, choices = NULL, selected = NULL, multiple = NULL) {
-
-  required_arguments <- c("choices",
-                          "selected",
-                          "multiple")
-
-  for(required_argument.i in required_arguments){
-    if(is.null(get(required_argument.i))){
-      stop(
-        material_missing_argument_error_message(
-          argument = required_argument.i,
-          input_id = input_id,
-          type = "dropdown",
-          additional_text =
+#' Create a shinymaterial dropdown
+#'
+#' Build a shinymaterial dropdown.
+#' @param input_id String. The input identifier used to access the value.
+#' @param label String. The dropdown label.
+#' @param choices Named vector. The option names and underyling values.
+#' @param selected String. The initially selected underyling value.
+#' @param multiple Boolean. Can multiple items be selected?
+#' @param color String. The color of the dropdown choices. Leave empty for the default color.
+#' @examples
+#' material_dropdown(
+#'   input_id = "example_dropdown",
+#'   label = "Drop down",
+#'   choices = c(
+#'     "Chicken" = "c",
+#'     "Steak" = "s",
+#'     "Fish" = "f"
+#'   ),
+#'   selected = c("c"),
+#'   multiple = FALSE,
+#'   color = "blue"
+#' )
+material_dropdown <- function(input_id, label, choices = NULL, selected = NULL, multiple = NULL, color = NULL){
+  
+  if(!is.null(color)){
+    
+    dropdown_style <-
+      shiny::tagList(
+        shiny::tags$head(
+          shiny::tags$style(
             paste0(
-              '\nSet selected = "no_selection" to select the first item in the list',
-              '\nSet multiple = TRUE for a multi-select'
+              '
+              #shiny-material-dropdown-', input_id, ' ul.dropdown-content.select-dropdown li span {
+              color: red;
+               }
+              '
             )
+          )
         )
       )
-    }
+    
+  } else {
+    dropdown_style <- shiny::tags$div()
   }
-
+  
   has_names <- !is.null(names(choices))
-
-  if(length(selected) > 1 & !multiple){
-    stop(
-      paste0(
-        "Argument 'selected' must be of length 1 when argument 'mutliple' = FALSE ",
-        "\ninput_id: ", input_id,
-        "\ntype: ", "dropdown"
-      )
-    )
-  }
-
+  
   if(length(selected) == 1){
-    if(selected == "no_selection"){
+    if(is.null(selected)){
       selected_index <- 1
     } else {
       selected_index <- which(choices == selected)
@@ -42,7 +54,7 @@ material_dropdown <- function(input_id, label, choices = NULL, selected = NULL,
   } else {
     selected_index <- which(choices %in% selected)
   }
-
+  
   material_option_tag_list <- shiny::tagList()
   #comment
   for(i in 1:length(choices)){
@@ -66,13 +78,14 @@ material_dropdown <- function(input_id, label, choices = NULL, selected = NULL,
         )
       )
   }
-
+  
   create_material_object(
     js_file = "shiny-material-dropdown.js",
     material_tag_list =
       shiny::tagList(
         shiny::tags$div(
           class = "input-field",
+          id = paste0('shiny-material-dropdown-', input_id),
           shiny::HTML(
             paste0(
               "<select", ifelse(multiple == TRUE, " multiple", ""),
@@ -86,7 +99,8 @@ material_dropdown <- function(input_id, label, choices = NULL, selected = NULL,
           shiny::tags$label(
             label
           )
-        )
+        ),
+        dropdown_style
       )
   )
 }
